##  Base AI Capabilities
Base AI capabilities in SAP LeanIX encompass the following features:
  * Inventory AI prompts use generative AI to provide a natural language interface for querying data, generating documentation, and obtaining insights in the inventory.
  * AI-assisted text simplifies text creation by analyzing content and context. Additionally, it transforms and enriches existing text to ensure clarity and accuracy. It is accessible in various areas, including fact sheet descriptions and other documentation.
  * AI-generated context aids users in understanding the tasks better by providing additional details and explanations. It is accessible, for example, in to-do tasks and surveys, assisting users in completing tasks efficiently.
  * AI-supported translation enables you to translate labels and help texts for fact sheet attributes in the meta model configuration.


For a more detailed guide on base AI capabilities, see [Base AI Capabilities](https://help.sap.com/docs/leanix/ea/base-ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX base AI capabilities make enterprise architecture data more accessible and actionable, offering natural language queries, AI-assisted text generation, contextual insights, and translation support.").
